<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Sólo la primera vez</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Responder a las conferencias</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Estado invisible</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Estado ocupado</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Estado disponible</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Respuesta automática</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Texto de la respuesta automática</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Elegir Estado</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Estoy ocupado.</translation>
    </message>
</context>
<context>
    <name>AutoresponderMessageFilter</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>Respuesta automática de Kadu:</translation>
    </message>
</context>
</TS>